==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkMultiProcessController.java <==
// java wrapper for vtkMultiProcessController object
//

package vtk;
import vtk.*;

public class vtkMultiProcessController extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Finalize_2();
  public void Finalize()
    { Finalize_2(); }

  private native void Finalize_3(int id0);
  public void Finalize(int id0)
    { Finalize_3(id0); }

  private native void SetNumberOfProcesses_4(int id0);
  public void SetNumberOfProcesses(int id0)
    { SetNumberOfProcesses_4(id0); }

  private native int GetNumberOfProcesses_5();
  public int GetNumberOfProcesses()
    { return GetNumberOfProcesses_5(); }

  private native void SetSingleProcessObject_6(vtkProcess id0);
  public void SetSingleProcessObject(vtkProcess id0)
    { SetSingleProcessObject_6(id0); }

  private native void SingleMethodExecute_7();
  public void SingleMethodExecute()
    { SingleMethodExecute_7(); }

  private native void MultipleMethodExecute_8();
  public void MultipleMethodExecute()
    { MultipleMethodExecute_8(); }

  private native int GetLocalProcessId_9();
  public int GetLocalProcessId()
    { return GetLocalProcessId_9(); }

  private native long GetGlobalController_10();
  public vtkMultiProcessController GetGlobalController() {
    long temp = GetGlobalController_10();

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void CreateOutputWindow_11();
  public void CreateOutputWindow()
    { CreateOutputWindow_11(); }

  private native long CreateSubController_12(vtkProcessGroup id0);
  public vtkMultiProcessController CreateSubController(vtkProcessGroup id0) {
    long temp = CreateSubController_12(id0);

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long PartitionController_13(int id0,int id1);
  public vtkMultiProcessController PartitionController(int id0,int id1) {
    long temp = PartitionController_13(id0,id1);

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int RemoveFirstRMI_14(int id0);
  public int RemoveFirstRMI(int id0)
    { return RemoveFirstRMI_14(id0); }

  private native int RemoveRMI_15(int id0);
  public int RemoveRMI(int id0)
    { return RemoveRMI_15(id0); }

  private native void RemoveAllRMICallbacks_16(int id0);
  public void RemoveAllRMICallbacks(int id0)
    { RemoveAllRMICallbacks_16(id0); }

  private native boolean RemoveRMICallback_17(int id0);
  public boolean RemoveRMICallback(int id0)
    { return RemoveRMICallback_17(id0); }

  private native void TriggerBreakRMIs_18();
  public void TriggerBreakRMIs()
    { TriggerBreakRMIs_18(); }

  private native void TriggerRMI_19(int id0,String id1,int id2);
  public void TriggerRMI(int id0,String id1,int id2)
    { TriggerRMI_19(id0,id1,id2); }

  private native void TriggerRMI_20(int id0,int id1);
  public void TriggerRMI(int id0,int id1)
    { TriggerRMI_20(id0,id1); }

  private native void TriggerRMIOnAllChildren_21(String id0,int id1);
  public void TriggerRMIOnAllChildren(String id0,int id1)
    { TriggerRMIOnAllChildren_21(id0,id1); }

  private native void TriggerRMIOnAllChildren_22(int id0);
  public void TriggerRMIOnAllChildren(int id0)
    { TriggerRMIOnAllChildren_22(id0); }

  private native int ProcessRMIs_23(int id0,int id1);
  public int ProcessRMIs(int id0,int id1)
    { return ProcessRMIs_23(id0,id1); }

  private native int ProcessRMIs_24();
  public int ProcessRMIs()
    { return ProcessRMIs_24(); }

  private native int BroadcastProcessRMIs_25(int id0,int id1);
  public int BroadcastProcessRMIs(int id0,int id1)
    { return BroadcastProcessRMIs_25(id0,id1); }

  private native void SetBreakFlag_26(int id0);
  public void SetBreakFlag(int id0)
    { SetBreakFlag_26(id0); }

  private native int GetBreakFlag_27();
  public int GetBreakFlag()
    { return GetBreakFlag_27(); }

  private native void SetBroadcastTriggerRMI_28(boolean id0);
  public void SetBroadcastTriggerRMI(boolean id0)
    { SetBroadcastTriggerRMI_28(id0); }

  private native boolean GetBroadcastTriggerRMI_29();
  public boolean GetBroadcastTriggerRMI()
    { return GetBroadcastTriggerRMI_29(); }

  private native void BroadcastTriggerRMIOn_30();
  public void BroadcastTriggerRMIOn()
    { BroadcastTriggerRMIOn_30(); }

  private native void BroadcastTriggerRMIOff_31();
  public void BroadcastTriggerRMIOff()
    { BroadcastTriggerRMIOff_31(); }

  private native long GetCommunicator_32();
  public vtkCommunicator GetCommunicator() {
    long temp = GetCommunicator_32();

    if (temp == 0) return null;
    return (vtkCommunicator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetBreakRMITag_33();
  public int GetBreakRMITag()
    { return GetBreakRMITag_33(); }

  private native int GetRMITag_34();
  public int GetRMITag()
    { return GetRMITag_34(); }

  private native int GetRMIArgTag_35();
  public int GetRMIArgTag()
    { return GetRMIArgTag_35(); }

  private native void Barrier_36();
  public void Barrier()
    { Barrier_36(); }

  private native void SetGlobalController_37(vtkMultiProcessController id0);
  public void SetGlobalController(vtkMultiProcessController id0)
    { SetGlobalController_37(id0); }

  private native int Send_38(String id0,int id1,int id2,int id3);
  public int Send(String id0,int id1,int id2,int id3)
    { return Send_38(id0,id1,id2,id3); }

  private native int Send_39(vtkDataObject id0,int id1,int id2);
  public int Send(vtkDataObject id0,int id1,int id2)
    { return Send_39(id0,id1,id2); }

  private native int Send_40(vtkDataArray id0,int id1,int id2);
  public int Send(vtkDataArray id0,int id1,int id2)
    { return Send_40(id0,id1,id2); }

  private native int Receive_41(String id0,int id1,int id2,int id3);
  public int Receive(String id0,int id1,int id2,int id3)
    { return Receive_41(id0,id1,id2,id3); }

  private native int Receive_42(vtkDataObject id0,int id1,int id2);
  public int Receive(vtkDataObject id0,int id1,int id2)
    { return Receive_42(id0,id1,id2); }

  private native int Receive_43(vtkDataArray id0,int id1,int id2);
  public int Receive(vtkDataArray id0,int id1,int id2)
    { return Receive_43(id0,id1,id2); }

  private native long ReceiveDataObject_44(int id0,int id1);
  public vtkDataObject ReceiveDataObject(int id0,int id1) {
    long temp = ReceiveDataObject_44(id0,id1);

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetCount_45();
  public int GetCount()
    { return GetCount_45(); }

  private native int Broadcast_46(String id0,int id1,int id2);
  public int Broadcast(String id0,int id1,int id2)
    { return Broadcast_46(id0,id1,id2); }

  private native int Broadcast_47(vtkDataObject id0,int id1);
  public int Broadcast(vtkDataObject id0,int id1)
    { return Broadcast_47(id0,id1); }

  private native int Broadcast_48(vtkDataArray id0,int id1);
  public int Broadcast(vtkDataArray id0,int id1)
    { return Broadcast_48(id0,id1); }

  private native int Gather_49(String id0,String id1,int id2,int id3);
  public int Gather(String id0,String id1,int id2,int id3)
    { return Gather_49(id0,id1,id2,id3); }

  private native int Gather_50(vtkDataArray id0,vtkDataArray id1,int id2);
  public int Gather(vtkDataArray id0,vtkDataArray id1,int id2)
    { return Gather_50(id0,id1,id2); }

  private native int GatherV_51(vtkDataArray id0,vtkDataArray id1,vtkIdTypeArray id2,vtkIdTypeArray id3,int id4);
  public int GatherV(vtkDataArray id0,vtkDataArray id1,vtkIdTypeArray id2,vtkIdTypeArray id3,int id4)
    { return GatherV_51(id0,id1,id2,id3,id4); }

  private native int GatherV_52(vtkDataArray id0,vtkDataArray id1,int id2);
  public int GatherV(vtkDataArray id0,vtkDataArray id1,int id2)
    { return GatherV_52(id0,id1,id2); }

  private native int Scatter_53(String id0,String id1,int id2,int id3);
  public int Scatter(String id0,String id1,int id2,int id3)
    { return Scatter_53(id0,id1,id2,id3); }

  private native int Scatter_54(vtkDataArray id0,vtkDataArray id1,int id2);
  public int Scatter(vtkDataArray id0,vtkDataArray id1,int id2)
    { return Scatter_54(id0,id1,id2); }

  private native int AllGather_55(String id0,String id1,int id2);
  public int AllGather(String id0,String id1,int id2)
    { return AllGather_55(id0,id1,id2); }

  private native int AllGather_56(vtkDataArray id0,vtkDataArray id1);
  public int AllGather(vtkDataArray id0,vtkDataArray id1)
    { return AllGather_56(id0,id1); }

  private native int AllGatherV_57(vtkDataArray id0,vtkDataArray id1);
  public int AllGatherV(vtkDataArray id0,vtkDataArray id1)
    { return AllGatherV_57(id0,id1); }

  private native int Reduce_58(String id0,String id1,int id2,int id3,int id4);
  public int Reduce(String id0,String id1,int id2,int id3,int id4)
    { return Reduce_58(id0,id1,id2,id3,id4); }

  private native int Reduce_59(vtkDataArray id0,vtkDataArray id1,int id2,int id3);
  public int Reduce(vtkDataArray id0,vtkDataArray id1,int id2,int id3)
    { return Reduce_59(id0,id1,id2,id3); }

  private native int AllReduce_60(String id0,String id1,int id2,int id3);
  public int AllReduce(String id0,String id1,int id2,int id3)
    { return AllReduce_60(id0,id1,id2,id3); }

  private native int AllReduce_61(vtkDataArray id0,vtkDataArray id1,int id2);
  public int AllReduce(vtkDataArray id0,vtkDataArray id1,int id2)
    { return AllReduce_61(id0,id1,id2); }

  public vtkMultiProcessController() { super(); }

  public vtkMultiProcessController(long id) { super(id); }

}

==> vtk-8.2.0-17-armv7h.pkg.tar.xz: vtk/vtkMultiProcessController.java <==
// java wrapper for vtkMultiProcessController object
//

package vtk;
import vtk.*;

public class vtkMultiProcessController extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Finalize_2();
  public void Finalize()
    { Finalize_2(); }

  private native void Finalize_3(int id0);
  public void Finalize(int id0)
    { Finalize_3(id0); }

  private native void SetNumberOfProcesses_4(int id0);
  public void SetNumberOfProcesses(int id0)
    { SetNumberOfProcesses_4(id0); }

  private native int GetNumberOfProcesses_5();
  public int GetNumberOfProcesses()
    { return GetNumberOfProcesses_5(); }

  private native void SetSingleProcessObject_6(vtkProcess id0);
  public void SetSingleProcessObject(vtkProcess id0)
    { SetSingleProcessObject_6(id0); }

  private native void SingleMethodExecute_7();
  public void SingleMethodExecute()
    { SingleMethodExecute_7(); }

  private native void MultipleMethodExecute_8();
  public void MultipleMethodExecute()
    { MultipleMethodExecute_8(); }

  private native int GetLocalProcessId_9();
  public int GetLocalProcessId()
    { return GetLocalProcessId_9(); }

  private native long GetGlobalController_10();
  public vtkMultiProcessController GetGlobalController() {
    long temp = GetGlobalController_10();

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void CreateOutputWindow_11();
  public void CreateOutputWindow()
    { CreateOutputWindow_11(); }

  private native long CreateSubController_12(vtkProcessGroup id0);
  public vtkMultiProcessController CreateSubController(vtkProcessGroup id0) {
    long temp = CreateSubController_12(id0);

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long PartitionController_13(int id0,int id1);
  public vtkMultiProcessController PartitionController(int id0,int id1) {
    long temp = PartitionController_13(id0,id1);

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int RemoveFirstRMI_14(int id0);
  public int RemoveFirstRMI(int id0)
    { return RemoveFirstRMI_14(id0); }

  private native int RemoveRMI_15(int id0);
  public int RemoveRMI(int id0)
    { return RemoveRMI_15(id0); }

  private native void RemoveAllRMICallbacks_16(int id0);
  public void RemoveAllRMICallbacks(int id0)
    { RemoveAllRMICallbacks_16(id0); }

  private native boolean RemoveRMICallback_17(int id0);
  public boolean RemoveRMICallback(int id0)
    { return RemoveRMICallback_17(id0); }

  private native void TriggerBreakRMIs_18();
  public void TriggerBreakRMIs()
    { TriggerBreakRMIs_18(); }

  private native void TriggerRMI_19(int id0,String id1,int id2);
  public void TriggerRMI(int id0,String id1,int id2)
    { TriggerRMI_19(id0,id1,id2); }

  private native void TriggerRMI_20(int id0,int id1);
  public void TriggerRMI(int id0,int id1)
    { TriggerRMI_20(id0,id1); }

  private native void TriggerRMIOnAllChildren_21(String id0,int id1);
  public void TriggerRMIOnAllChildren(String id0,int id1)
    { TriggerRMIOnAllChildren_21(id0,id1); }

  private native void TriggerRMIOnAllChildren_22(int id0);
  public void TriggerRMIOnAllChildren(int id0)
    { TriggerRMIOnAllChildren_22(id0); }

  private native int ProcessRMIs_23(int id0,int id1);
  public int ProcessRMIs(int id0,int id1)
    { return ProcessRMIs_23(id0,id1); }

  private native int ProcessRMIs_24();
  public int ProcessRMIs()
    { return ProcessRMIs_24(); }

  private native int BroadcastProcessRMIs_25(int id0,int id1);
  public int BroadcastProcessRMIs(int id0,int id1)
    { return BroadcastProcessRMIs_25(id0,id1); }

  private native void SetBreakFlag_26(int id0);
  public void SetBreakFlag(int id0)
    { SetBreakFlag_26(id0); }

  private native int GetBreakFlag_27();
  public int GetBreakFlag()
    { return GetBreakFlag_27(); }

  private native void SetBroadcastTriggerRMI_28(boolean id0);
  public void SetBroadcastTriggerRMI(boolean id0)
    { SetBroadcastTriggerRMI_28(id0); }

  private native boolean GetBroadcastTriggerRMI_29();
  public boolean GetBroadcastTriggerRMI()
    { return GetBroadcastTriggerRMI_29(); }

  private native void BroadcastTriggerRMIOn_30();
  public void BroadcastTriggerRMIOn()
    { BroadcastTriggerRMIOn_30(); }

  private native void BroadcastTriggerRMIOff_31();
  public void BroadcastTriggerRMIOff()
    { BroadcastTriggerRMIOff_31(); }

  private native long GetCommunicator_32();
  public vtkCommunicator GetCommunicator() {
    long temp = GetCommunicator_32();

    if (temp == 0) return null;
    return (vtkCommunicator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetBreakRMITag_33();
  public int GetBreakRMITag()
    { return GetBreakRMITag_33(); }

  private native int GetRMITag_34();
  public int GetRMITag()
    { return GetRMITag_34(); }

  private native int GetRMIArgTag_35();
  public int GetRMIArgTag()
    { return GetRMIArgTag_35(); }

  private native void Barrier_36();
  public void Barrier()
    { Barrier_36(); }

  private native void SetGlobalController_37(vtkMultiProcessController id0);
  public void SetGlobalController(vtkMultiProcessController id0)
    { SetGlobalController_37(id0); }

  private native int Send_38(String id0,int id1,int id2,int id3);
  public int Send(String id0,int id1,int id2,int id3)
    { return Send_38(id0,id1,id2,id3); }

  private native int Send_39(vtkDataObject id0,int id1,int id2);
  public int Send(vtkDataObject id0,int id1,int id2)
    { return Send_39(id0,id1,id2); }

  private native int Send_40(vtkDataArray id0,int id1,int id2);
  public int Send(vtkDataArray id0,int id1,int id2)
    { return Send_40(id0,id1,id2); }

  private native int Receive_41(String id0,int id1,int id2,int id3);
  public int Receive(String id0,int id1,int id2,int id3)
    { return Receive_41(id0,id1,id2,id3); }

  private native int Receive_42(vtkDataObject id0,int id1,int id2);
  public int Receive(vtkDataObject id0,int id1,int id2)
    { return Receive_42(id0,id1,id2); }

  private native int Receive_43(vtkDataArray id0,int id1,int id2);
  public int Receive(vtkDataArray id0,int id1,int id2)
    { return Receive_43(id0,id1,id2); }

  private native long ReceiveDataObject_44(int id0,int id1);
  public vtkDataObject ReceiveDataObject(int id0,int id1) {
    long temp = ReceiveDataObject_44(id0,id1);

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetCount_45();
  public int GetCount()
    { return GetCount_45(); }

  private native int Broadcast_46(String id0,int id1,int id2);
  public int Broadcast(String id0,int id1,int id2)
    { return Broadcast_46(id0,id1,id2); }

  private native int Broadcast_47(vtkDataObject id0,int id1);
  public int Broadcast(vtkDataObject id0,int id1)
    { return Broadcast_47(id0,id1); }

  private native int Broadcast_48(vtkDataArray id0,int id1);
  public int Broadcast(vtkDataArray id0,int id1)
    { return Broadcast_48(id0,id1); }

  private native int Gather_49(String id0,String id1,int id2,int id3);
  public int Gather(String id0,String id1,int id2,int id3)
    { return Gather_49(id0,id1,id2,id3); }

  private native int Gather_50(vtkDataArray id0,vtkDataArray id1,int id2);
  public int Gather(vtkDataArray id0,vtkDataArray id1,int id2)
    { return Gather_50(id0,id1,id2); }

  private native int GatherV_51(vtkDataArray id0,vtkDataArray id1,vtkIdTypeArray id2,vtkIdTypeArray id3,int id4);
  public int GatherV(vtkDataArray id0,vtkDataArray id1,vtkIdTypeArray id2,vtkIdTypeArray id3,int id4)
    { return GatherV_51(id0,id1,id2,id3,id4); }

  private native int GatherV_52(vtkDataArray id0,vtkDataArray id1,int id2);
  public int GatherV(vtkDataArray id0,vtkDataArray id1,int id2)
    { return GatherV_52(id0,id1,id2); }

  private native int Scatter_53(String id0,String id1,int id2,int id3);
  public int Scatter(String id0,String id1,int id2,int id3)
    { return Scatter_53(id0,id1,id2,id3); }

  private native int Scatter_54(vtkDataArray id0,vtkDataArray id1,int id2);
  public int Scatter(vtkDataArray id0,vtkDataArray id1,int id2)
    { return Scatter_54(id0,id1,id2); }

  private native int AllGather_55(String id0,String id1,int id2);
  public int AllGather(String id0,String id1,int id2)
    { return AllGather_55(id0,id1,id2); }

  private native int AllGather_56(vtkDataArray id0,vtkDataArray id1);
  public int AllGather(vtkDataArray id0,vtkDataArray id1)
    { return AllGather_56(id0,id1); }

  private native int AllGatherV_57(vtkDataArray id0,vtkDataArray id1);
  public int AllGatherV(vtkDataArray id0,vtkDataArray id1)
    { return AllGatherV_57(id0,id1); }

  private native int Reduce_58(String id0,String id1,int id2,int id3,int id4);
  public int Reduce(String id0,String id1,int id2,int id3,int id4)
    { return Reduce_58(id0,id1,id2,id3,id4); }

  private native int Reduce_59(vtkDataArray id0,vtkDataArray id1,int id2,int id3);
  public int Reduce(vtkDataArray id0,vtkDataArray id1,int id2,int id3)
    { return Reduce_59(id0,id1,id2,id3); }

  private native int AllReduce_60(String id0,String id1,int id2,int id3);
  public int AllReduce(String id0,String id1,int id2,int id3)
    { return AllReduce_60(id0,id1,id2,id3); }

  private native int AllReduce_61(vtkDataArray id0,vtkDataArray id1,int id2);
  public int AllReduce(vtkDataArray id0,vtkDataArray id1,int id2)
    { return AllReduce_61(id0,id1,id2); }

  public vtkMultiProcessController() { super(); }

  public vtkMultiProcessController(long id) { super(id); }

}
